=======
Credits
=======

Development Lead
----------------

* Daniel Greenfeld <pydanny@gmail.com>
* Buddy Lindsley
* Yasmine Charif (@dollydagr)

Contributors
------------

* Audrey Roy
* Luis Montiel <luismmontielg@gmail.com>
* Kulbir Singh (@kulbir)
